# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-EV
Version:	4.22
Release:	2.%{__distinit}%{__distvers}
Summary:	Wrapper for the libev high-performance event loop library
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/EV/
Source0:	http://search.cpan.org/CPAN/authors/id/M/ML/MLEHMANN/EV-%{version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# Module Build
BuildRequires:	gdbm-devel
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 6 || 0%{?rhel} > 5
BuildRequires:	perl-devel
%endif
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(AnyEvent) >= 5.29
BuildRequires:	perl(Canary::Stability)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(strict)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(common::sense)
BuildRequires:	perl(Config)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Socket)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%{?perl_default_filter}

%description
This module provides an interface to libev
(<http://software.schmorp.de/pkg/libev.html>).

%prep
%setup -q -n EV-%{version}

%build
PERL_MM_USE_DEFAULT=1 perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}" < /dev/null
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license COPYING
%else
%doc COPYING
%endif
%doc Changes README
%dir %{perl_vendorarch}/EV/
%doc %{perl_vendorarch}/EV/libev.pod
%{perl_vendorarch}/EV.pm
%{perl_vendorarch}/EV/*.h
%{perl_vendorarch}/EV/MakeMaker.pm
%{perl_vendorarch}/auto/EV/
%{_mandir}/man3/EV.3*
%{_mandir}/man3/EV::MakeMaker.3*
%{_mandir}/man3/EV::libev.3*

%changelog
* Mon Aug 22 2016 Paul Howarth <paul@city-fan.org> - 4.22-2
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Mon Dec 21 2015 Paul Howarth <paul@city-fan.org> - 4.22-1
- Update to 4.22
  - (libev) When epoll detects unremovable fds in the fd set, rebuild only the
    epoll descriptor, not the signal pipe, to avoid SIGPIPE in ev_async_send;
    this doesn't solve it on fork, so document what needs to be done in
    ev_loop_fork
  - (libev) Remove superfluous sys/timeb.h include on win32
  - Updated libecb
- Explicitly BR: perl-devel, needed for EXTERN.h

* Tue Jul 14 2015 Paul Howarth <paul@city-fan.org> - 4.21-1
- Update to 4.21
  - Allow argument in timer->again
  - Document timer->remaining
  - Document default repeat value for timer->set

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 4.20-1
- Update to 4.20
  - Added stability canary support
  - Truly rely on automatic configuration for clock_gettime and others;
    unfortunately, this doesn't help with activeperl and similar perls, which
    define _POSIX_TIMERS without actually implementing any of it
  - (libev, ecb) Make it compile as C++ again
  - (libev) Fix a potential aliasing issue when accessing watcher callbacks
- Classify buildreqs by usage

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 4.18-1
- Update to 4.18
  - Use slightly better way to find includes, to support multiarch on newer
    perls
- Use %%license where possible

* Fri Apr 11 2014 Paul Howarth <paul@city-fan.org> - 4.17-1
- Update to 4.17
  - perl5porters broke Async::Interrupt, BDB, EV, IO::AIO and OpenCL without
    warning by switching the meaning of USE_SOCKETS_AS_HANDLES in 5.18
- Drop %%defattr, redundant since rpm 4.4

* Sat Mar  8 2014 Paul Howarth <paul@city-fan.org> - 4.16-1
- Update to 4.16
  - Make sure EV::CHECK is available at all times
  - Avoid a spurious warning when perl -w overrides "no warnings"
  - Use perl's signal implementation on WIN32
  - Ensure extern "C" function pointers are used for externally-visible
    pointers
  - (libev) mark event pipe fd as cloexec after a fork
  - (ecb) support m68k, m88k and sh
  - (libev) in the absence of autoconf, do not use the clock syscall on
    glibc ≥ 2.17 (avoids the syscall AND -lrt on systems doing clock_gettime
    in userspace)
  - (ecb) work around memory barriers and volatile apparently both being broken
    in Visual Studio 2008 and later

* Fri Mar  1 2013 Paul Howarth <paul@city-fan.org> - 4.15-1
- Update to 4.15
  - (libev) upgrade to 4.15 - too many changes to list
  - EV::run now returns a boolean
  - API version 5:1
    - Document that cleanup watchers are not available via perl
    - Cast I32 to int in error message printf
    - Remove dependencies on librt and libpthreads on GNU/Linux

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 4.11-2
- Use local dist tag definition rather than %%{?dist}
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation
  - Drop rpath-fixing kludge

* Sun Feb  5 2012 Paul Howarth <paul@city-fan.org> - 4.11-1
- Update to 4.11
  - libev: Implement memory fences for (obsolete) llvm-gcc

* Thu Jan 19 2012 Paul Howarth <paul@city-fan.org> - 4.10-1
- Update to 4.10
  - libev: Fix a race where the workaround against the epoll fork bugs caused
    signals to not be handled anymore
  - libev: Correct backend_fudge for most backends, and implement a Windows
    specific workaround to avoid looping because we call both select and Sleep,
    with different time resolutions
  - e_new wasn't declared static (causing very minor .so bloat)
  - replace more old API names by new ones
- BR: perl(Config)

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 4.03-6
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Install into vendor directories rather than perl directories
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jan 26 2011 Paul Howarth <paul@city-fan.org> - 4.03-2
- Import from Fedora review queue (#448613)
- Always build with bundled libev

* Mon Jan 24 2011 Mathieu Bridon <bochecha@fedoraproject.org> - 4.03-1
- Update to 4.03

* Sun Nov  8 2009 kwizart < kwizart at gmail.com > - 3.8-1
- Update to 3.8

* Tue Apr 28 2009 kwizart < kwizart at gmail.com > - 3.6-1
- Update to 3.6

* Mon Mar  2 2009 kwizart < kwizart at gmail.com > - 3.53-1
- Update to 3.53

* Tue Feb  3 2009 kwizart < kwizart at gmail.com > - 3.52-1
- Update to 3.52

* Tue Oct 14 2008 kwizart < kwizart at gmail.com > - 3.44-1
- Update to 3.44
- WIP conditional --with systemlibev

* Tue Jul 15 2008 kwizart < kwizart at gmail.com > - 3.431-1
- Update to 3.431
- Update License to (GPL+ or Artistic) and (BSD or GPLv2+)
- Add libev README and LICENSE

* Tue Jul  8 2008 kwizart < kwizart at gmail.com > - 3.43-1
- Update to 3.43

* Mon Jun  9 2008 kwizart < kwizart at gmail.com > - 3.42-2
- Disable filter AnyEvent

* Tue May 27 2008 kwizart < kwizart at gmail.com > - 3.42-1
- Update to 3.42

* Wed Apr 30 2008 kwizart < kwizart at gmail.com > - 3.31-1
- Initial package for Fedora
